<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=ro
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Întoarcere la interfaţa grafică completă',
	'access_mode_texte' => 'Afişaţi interfaţa textuală simplă',
	'admin_debug' => 'depanare',
	'admin_modifier_article' => 'Modificaţi articolul',
	'admin_modifier_auteur' => 'Modificaţi autorul',
	'admin_modifier_breve' => 'Modificaţi ştirea',
	'admin_modifier_mot' => 'Modificaţi cuvântul cheie',
	'admin_modifier_rubrique' => 'Modificaţi rubrica',
	'admin_recalculer' => 'Recalculaţi această pagină',
	'afficher_calendrier' => 'Afişaţi calendarul',
	'afficher_trad' => 'afişaţi traducerile',
	'alerte_maj_impossible' => '<b>Alertă !</b> Aducerea la zi a bazei de date SQL către versiunea @version@ este imposibilă, probabil din cauza unei probleme de drepturi de modificare în baza de date. Vă rugăm să contactaţi furnizorul dumneavoastră de hosting.',
	'alerte_modif_info_concourante' => 'ATENŢIE : Această informaţie a fost modificată. Valoarea curentă este :',
	'analyse_xml' => 'Analiză XML',
	'annuler' => 'Anulaţi',
	'antispam_champ_vide' => 'Vă rugăm să lăsaţi acest câmp gol :',
	'articles_recents' => 'Cele mai recente articole',
	'avis_archive_incorrect' => 'fişierul arhivă nu este de tip SPIP',
	'avis_archive_invalide' => 'fişierul arhivă nu este valid',
	'avis_attention' => 'Atenţie!',
	'avis_champ_incorrect_type_objet' => 'Numele de câmp @name@ este incorect pentru obiecte de tip @type@ ',
	'avis_colonne_inexistante' => 'Coloana @col@ nu există',
	'avis_erreur' => 'Eroare: vedeţi mai jos',
	'avis_erreur_connexion' => 'Eroare de conexiune',
	'avis_erreur_cookie' => 'problemă de cookie',
	'avis_erreur_fonction_contexte' => 'Eroare de programare. Această funcţie nu trebuie chemată în acest context.',
	'avis_erreur_mysql' => 'Eroare SQL',
	'avis_erreur_sauvegarde' => 'Eroare în timpul salvării (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Problemă de acces în secţiunea privată',

	// B
	'barre_a_accent_grave' => 'Inseraţi un A majuscul cu accent grav',
	'barre_aide' => 'Utilizaţi secvențele tipografice pentru a îmbogăţi aranjarea în pagină',
	'barre_e_accent_aigu' => 'Inseraţi un E majuscul cu accent ascuţit',
	'barre_eo' => 'Inseraţi un E în O',
	'barre_eo_maj' => 'Inseraţi un E în O majuscul',
	'barre_euro' => 'Inseraţi simbolul €',
	'barre_gras' => 'Transformaţi în litere {{aldine}} (îngroşate)',
	'barre_guillemets' => 'Înconjuraţi cu « ghilimele »',
	'barre_guillemets_simples' => 'Înconjuraţi cu “ghilimele de nivel secund”',
	'barre_intertitre' => 'Transformaţi în {{{inter-titlu}}}',
	'barre_italic' => 'Transformaţi în litere {{italice}} (înclinate)',
	'barre_lien' => 'Transformaţi în [legătură hipertext->http://...]',
	'barre_lien_input' => 'Vă rugăm să indicaţi adresa legăturii dumneavoastră (puteţi indica o adresă de Web sub forma http://www.situlmeu.ro sau chiar numai numărul unui articol de pe acest site).',
	'barre_note' => 'Transformaţi în [[Notă în josul paginii]]',
	'barre_paragraphe' => 'Creaţi un paragraf',
	'barre_quote' => '<quote>Citaţi un mesaj</quote>',
	'bouton_changer' => 'Schimbaţi',
	'bouton_chercher' => 'Căutaţi',
	'bouton_choisir' => 'Alegeţi',
	'bouton_deplacer' => 'Deplasaţi',
	'bouton_download' => 'Descărcaţi',
	'bouton_enregistrer' => 'Înregistraţi',
	'bouton_radio_desactiver_messagerie_interne' => 'Dezactivaţi mesageria internă',
	'bouton_radio_envoi_annonces' => 'Trimiteţi anunţurile editoriale',
	'bouton_radio_non_envoi_annonces' => 'Nu trimiteţi anunţuri',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Nu trimiteţi lista de noutăţi',
	'bouton_recharger_page' => 're-încărcați această pagină',
	'bouton_telecharger' => 'Descărcaţi',
	'bouton_upload' => 'Încărcaţi',
	'bouton_valider' => 'Validaţi',

	// C
	'cal_apresmidi' => 'După-amiază',
	'cal_jour_entier' => 'toată ziua',
	'cal_matin' => 'dimineaţa',
	'cal_par_jour' => 'calendar pe zi',
	'cal_par_mois' => 'calendar pe lună',
	'cal_par_semaine' => 'calendar pe săptămână',
	'choix_couleur_interface' => 'culoare',
	'choix_interface' => 'alegerea interfeţei',
	'colonne' => 'Coloană',
	'confirm_changer_statut' => 'Atenţie, aţi cerut schimbarea stării acestui element. Doriţi să continuaţi ?',
	'correcte' => 'corectă',

	// D
	'date_aujourdhui' => 'astăzi',
	'date_avant_jc' => 'înaintea erei noastre',
	'date_dans' => 'în @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'mâine',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour_heure' => '@jour@ la @heure@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => '@nomjour@ @date@',
	'date_fmt_periode_from' => 'De la',
	'date_fmt_periode_to' => 'la',
	'date_heures' => 'ore',
	'date_hier' => 'ieri',
	'date_il_y_a' => 'acum @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Duminică',
	'date_jour_1_abbr' => 'dum.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'Luni',
	'date_jour_2_abbr' => 'lun.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'Marţi',
	'date_jour_3_abbr' => 'mar.',
	'date_jour_3_initiale' => 'ma.',
	'date_jour_4' => 'Miercuri',
	'date_jour_4_abbr' => 'mie.',
	'date_jour_4_initiale' => 'mi.',
	'date_jour_5' => 'Joi',
	'date_jour_5_abbr' => 'joi',
	'date_jour_5_initiale' => 'j.',
	'date_jour_6' => 'Vineri',
	'date_jour_6_abbr' => 'vin.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'Sâmbătă',
	'date_jour_7_abbr' => 'sâm.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'zile',
	'date_minutes' => 'minute',
	'date_mois' => 'luni',
	'date_mois_1' => 'ianuarie',
	'date_mois_10' => 'octombrie',
	'date_mois_10_abbr' => 'oct.',
	'date_mois_11' => 'noiembrie',
	'date_mois_11_abbr' => 'noi.',
	'date_mois_12' => 'decembrie',
	'date_mois_12_abbr' => 'dec.',
	'date_mois_1_abbr' => 'ian.',
	'date_mois_2' => 'februarie',
	'date_mois_2_abbr' => 'feb.',
	'date_mois_3' => 'martie',
	'date_mois_3_abbr' => 'mar.',
	'date_mois_4' => 'aprilie',
	'date_mois_4_abbr' => 'apr.',
	'date_mois_5' => 'mai',
	'date_mois_5_abbr' => 'mai',
	'date_mois_6' => 'iunie',
	'date_mois_6_abbr' => 'iun.',
	'date_mois_7' => 'iulie',
	'date_mois_7_abbr' => 'iul.',
	'date_mois_8' => 'august',
	'date_mois_8_abbr' => 'aug.',
	'date_mois_9' => 'septembrie',
	'date_mois_9_abbr' => 'sep.',
	'date_saison_1' => 'iarna',
	'date_saison_2' => 'primăvara',
	'date_saison_3' => 'vara',
	'date_saison_4' => 'toamna',
	'date_secondes' => 'secunde',
	'date_semaines' => 'săptămâni',
	'date_un_mois' => 'luna',
	'date_une_heure' => 'ora',
	'date_une_minute' => 'minut',
	'date_une_seconde' => 'secunda',
	'date_une_semaine' => 'saptamana',
	'dirs_commencer' => ' pentru a începe cu adevărat instalarea',
	'dirs_preliminaire' => 'Preliminar : <b>Reglaţi drepturile de acces</b>',
	'dirs_probleme_droits' => 'Problemă de drepturi de acces',
	'dirs_repertoires_absents' => '<p><b>Următoarele directoare nu au fost găsite :</b></p> <ul>@bad_dirs@.</ul>
  <p>Cel mai probabil, această situaţie este datorată unei probleme de litere majuscule sau minuscule.
 Verificați ca litere majuscule şi minuscule a acestor directoare să concorde cu ceea ce este afişat
 mai sus; dacă nu este cazul, redenumiți directoarele cu ajutorul programului dumneavoastră favorit de FTP pentru a corecta eroarea.
  <p>Odată terminată această manipulare, puteți ',
	'dirs_repertoires_suivants' => '<p><b>Directoarele următoare nu sunt accesibile în mod scriere :</b></p> <ul>@bad_dirs@.</ul>
  <p>Pentru a remedia această problemă, utilizaţi clientul dumneavoastră favorit de FTP pentru a modifica drepturile de acces ale fiecărui
  dintre aceste directoare. Procedura este explicată în detaliu în manualul de instalare.</p>
  <p>Odată terminată această manipulare, puteţi ',
	'double_occurrence' => 'Ocurenţă dublă a @balise@',

	// E
	'en_cours' => 'în curs',
	'envoi_via_le_site' => 'Trimitere via site',
	'erreur' => 'Eroare',
	'erreur_balise_non_fermee' => 'ultima baliză (tag) ne-închisă:',
	'erreur_texte' => 'eroare(i)',
	'etape' => 'Etapă',

	// F
	'fichier_introuvable' => 'Fişier @fichier@ de negăsit', # MODIF
	'form_auteur_confirmation' => 'Confirmaţi adresa dumneavoastră de email',
	'form_auteur_email_modifie' => 'Adresa dumneavoastră de email a fost modificată.',
	'form_auteur_envoi_mail_confirmation' => 'Un email de confirmare a fost trimis la @email@. Trebuie să vizitaţi adresa de web menţionată în email pentru a valida adresa de email.',
	'form_auteur_mail_confirmation' => 'Bună ziua,

Aţi cerut modificarea dresei dumneavoastră de email.
Pentru a confirma noua adresă, e suficient să vă conectaţi la
adresa de mai jos (în caz contrat cererea dumneavoastră va fi ignorată) :

    @url@
',
	'form_deja_inscrit' => 'Sunteţi deja înscris.',
	'form_email_non_valide' => 'Adresa dumneavoastră de email nu este valabilă.',
	'form_forum_access_refuse' => 'Nu mai aveţi dreptul de acces la acest site.',
	'form_forum_bonjour' => 'Bun? ziua @nom@,',
	'form_forum_confirmer_email' => 'Pentru a confirma adresa dvs. de email, vizitaţi această adresă: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Această adresă de email este deja înregistrată. Puteţi, aşadar, utiliza parola dumneavoastră obişnuită.',
	'form_forum_identifiant_mail' => 'Noul dumneavoastră identificator tocmai v-a fost trimis pe email.',
	'form_forum_identifiants' => 'Identificatori personali',
	'form_forum_indiquer_nom_email' => 'Indicaţi aici numele și adresa dumneavoastra de email. Identificatorul dumneavoastră personal vă va parveni în scurt timp prin email.',
	'form_forum_login' => 'login :',
	'form_forum_message_auto' => '(acesta este un mesaj automatic)',
	'form_forum_pass' => 'parola :',
	'form_forum_probleme_mail' => 'Problemă de email : identificatorul nu poate fi trimis.',
	'form_forum_voici1' => 'Iată identificatorii dumneavoastră pentru a participa la activitatea
site-ului "@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Iată identificatorii dvs. pentru a putea propune articole pe
site-ul "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Vă rugăm sa indicaţi adresa dumneavoastră de email.',
	'form_indiquer_nom' => 'Va rugăm să indicaţi numele dumneavoastră.',
	'form_indiquer_nom_site' => 'Vă rugăm să indicaţi adresa site-ul dumneavoastră de web.',
	'form_pet_deja_enregistre' => 'Acest site este deja înregistrat',
	'form_pet_signature_pasprise' => 'Semnătura dumneavoastră nu a fost luată în considerare.',
	'form_prop_confirmer_envoi' => 'Confirmaţi trimiterea',
	'form_prop_description' => 'Descriere/comentariu',
	'form_prop_enregistre' => 'Propunerea dumneavoastră a fost înregistrată, ea va fi publicată după validarea ei de către responsabilii acestui site.', # MODIF
	'form_prop_envoyer' => 'Trimiteţi un mesaj',
	'form_prop_indiquer_email' => 'Vă rugăm să indicaţi o adresă de email valabilă',
	'form_prop_indiquer_nom_site' => 'Va rugăm să indicaţi numele site-ului.',
	'form_prop_indiquer_sujet' => 'Va rugăm să indicaţi un subiect',
	'form_prop_message_envoye' => 'Mesaj trimis',
	'form_prop_non_enregistre' => 'Propunerea dumneavoastră nu a fost înregistrată.',
	'form_prop_sujet' => 'Subiect',
	'form_prop_url_site' => 'Adresa (URL-ul) site-ului', # MODIF
	'forum_non_inscrit' => 'Nu sunteţi înscris, sau adresa ori parola dumneavoastră nu sunt corecte.',
	'forum_par_auteur' => 'de @auteur@',
	'forum_titre_erreur' => 'Eroare...',

	// I
	'ical_texte_rss_articles' => 'Fişierul «backend» al articolelor acestui site se găseşte la adresa:',
	'ical_texte_rss_articles2' => 'Puteţi, de asemenea, obţine fişierele «backend» pentru articolele fiecărei rubrici de pe site:',
	'ical_texte_rss_breves' => 'Există, de asemenea, un fişier conţinând ştirile acestui site. Precizând numărul rubricii, veţi obţine doar ştirile acelei rubrici.',
	'icone_a_suivre' => 'Prima pagină',
	'icone_admin_site' => 'Administrarea site-ului',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Ajutor',
	'icone_articles' => 'Articole',
	'icone_auteurs' => 'Autori',
	'icone_brouteur' => 'Navigare rapidă',
	'icone_configuration_site' => 'Configurare',
	'icone_configurer_site' => 'Configuraţi-vă site-ul',
	'icone_creer_nouvel_auteur' => 'Creaţi un nou autor',
	'icone_creer_rubrique' => 'Creaţi o rubrică',
	'icone_creer_sous_rubrique' => 'Creaţi o sub-rubrică',
	'icone_deconnecter' => 'Deconectaţi-vă',
	'icone_discussions' => 'Discuţii',
	'icone_doc_rubrique' => 'Documentele rubricilor',
	'icone_ecrire_article' => 'Scrieţi un nou articol',
	'icone_edition_site' => 'Editaţi',
	'icone_gestion_langues' => 'Gestiunea limbilor',
	'icone_informations_personnelles' => 'Informaţii personale',
	'icone_interface_complet' => 'interfaţa completă',
	'icone_interface_simple' => 'interfaţa simplificată',
	'icone_maintenance_site' => 'Întreţinerea site-ului',
	'icone_messagerie_personnelle' => 'Mesageria personală',
	'icone_repartition_debut' => 'Afişaţi repartiţia de la început',
	'icone_rubriques' => 'Rubrici',
	'icone_sauver_site' => 'Salvarea site-ului',
	'icone_site_entier' => 'Tot site-ul',
	'icone_sites_references' => 'Site-uri referenţiate',
	'icone_statistiques' => 'Statisticile site-ului',
	'icone_suivi_activite' => 'Urmăriţi activitatea site-ului',
	'icone_suivi_actualite' => 'Evoluţia site-ului',
	'icone_suivi_pettions' => 'Urmăriţi/gestionaţi petiţiile',
	'icone_suivi_revisions' => 'Modificări ale articolelor',
	'icone_supprimer_document' => 'Suprimaţi acest document',
	'icone_supprimer_image' => 'Suprimaţi această imagine',
	'icone_tous_articles' => 'Toate articolele dvs.',
	'icone_tous_auteur' => 'Toţi autorii',
	'icone_tous_visiteur' => 'Toţi vizitatorii',
	'icone_visiter_site' => 'Vizitaţi site-ul public',
	'icone_voir_en_ligne' => 'Vedeţi în direct',
	'img_indisponible' => 'imagine nedisponibilă',
	'impossible' => 'imposibil',
	'info_a_suivre' => 'DE URMĂRIT »',
	'info_acces_interdit' => 'Acces interzis',
	'info_acces_refuse' => 'Acces refuzat',
	'info_action' => 'Acțiune : @action@',
	'info_administrer_rubriques' => 'Puteţi administra această rubrică şi sub-rubricile ei',
	'info_adresse_non_indiquee' => 'Nu aţi indicat adresa de testat !',
	'info_aide' => 'AJUTOR :',
	'info_ajouter_mot' => 'Adăugaţi acest cuvânt',
	'info_annonce' => 'ANUNŢ',
	'info_annonces_generales' => 'Anunţuri generale :',
	'info_article_propose' => 'Articol propus',
	'info_article_publie' => 'Articol publicat',
	'info_article_redaction' => 'Articol în curs de redactare',
	'info_article_refuse' => 'Articol refuzat',
	'info_article_supprime' => 'Articol suprimat',
	'info_articles' => 'Articole',
	'info_articles_a_valider' => 'Articole pentru validare',
	'info_articles_nb' => '@nb@ articole',
	'info_articles_proposes' => 'Articole propuse',
	'info_articles_un' => '1 articol',
	'info_auteurs_nombre' => 'autor(i) :',
	'info_authentification_ftp' => 'Autentificare (prin FTP).',
	'info_breves_2' => 'ştiri',
	'info_breves_nb' => '@nb@ ştiri',
	'info_breves_un' => '1 ştire',
	'info_connexion_refusee' => 'Conexiune refuzată',
	'info_contact_developpeur' => 'Vă rugăm să contactaţi un dezvoltator.', # MODIF
	'info_contenance' => 'Acest site conţine :',
	'info_contribution' => 'contribuţii',
	'info_copyright' => '@spip@ este un program liber distribuit @lien_gpl@.',
	'info_copyright_doc' => 'Pentru mai multe informaţii, vizitaţi site-ul <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'sub licenţă GPL',
	'info_cours_edition' => 'În curs de redactare', # MODIF
	'info_creer_repertoire' => 'Vă rugăm să creaţi un fișier sau un director numit :',
	'info_creer_repertoire_2' => 'sub directorul <b>@repertoire@</b>, apoi :',
	'info_creer_vignette' => 'crearea viniétei în mod automat ',
	'info_deplier' => 'Desfaceţi',
	'info_descriptif_nombre' => 'descriere(i) :',
	'info_description' => 'Descriere :',
	'info_description_2' => 'Descriere :',
	'info_dimension' => 'Dimensiuni :',
	'info_documents_nb' => '@nb@ documente',
	'info_documents_un' => '1 document',
	'info_ecire_message_prive' => 'Scrieţi un nou mesaj privat',
	'info_email_invalide' => 'Adresă invalidă de email.',
	'info_en_cours_validation' => 'Articolele dvs. în curs de redactare',
	'info_en_ligne' => 'În acest moment în linie :',
	'info_envoyer_message_prive' => 'Trimiteţi un mesaj privat acestui autor',
	'info_erreur_requete' => 'Eroare în cererea :',
	'info_erreur_squelette2' => 'Nici un schelet <b>@fichier@</b> nu este disponibil...',
	'info_erreur_systeme' => 'Eroare sistem (errno @errsys@)',
	'info_erreur_systeme2' => 'Discul este probabil plin sau baza de date este coruptă.<br />
<span style="color:red;">Încercaţi să <a href=\'@script@\'>reparaţi baza de date</a>, sau contactaţi-l pe furnizorul dumneavoastră de internet.</span>',
	'info_fini' => 'Este gata !',
	'info_format_image' => 'Formatele de imagini care pot fi folosite la crearea viniételor : @gd_formats@.',
	'info_format_non_defini' => 'format nedefinit',
	'info_grand_ecran' => 'Ecran mare',
	'info_image_aide' => 'AJUTOR',
	'info_image_process_titre' => 'Metoda pentru elaborarea vinietelor',
	'info_impossible_lire_page' => '<b>Eroare !</b> Imposibil de citit pagina <tt><html>@test_proxy@</html></tt> prin intermediul proxy-ului',
	'info_installation_systeme_publication' => 'Instalarea sistemului de publicare...',
	'info_installer_documents' => 'Puteţi instala în mod automat toate documentele conţinute în directorul @upload@.',
	'info_installer_ftp' => 'Ca administrator, puteţi să instalaţi (prin FTP) fişiere în directorul @upload@ pentru ca mai apoi să le selecţionaţi direct aici.', # MODIF
	'info_installer_images' => 'Puteţi instala imagini în formatele JPEG, GIF şi PNG.',
	'info_installer_images_dossier' => 'Instalaţi imagini în directorul @upload@ pentru a putea să le selecţionaţi aici.',
	'info_interface_complete' => 'interfaţa completă',
	'info_interface_simple' => 'Interfaţa simplificată',
	'info_joindre_document_article' => 'Puteţi să ataşaţi acestui articol documente de tipul',
	'info_joindre_document_rubrique' => 'Puteţi să ataşaţi acestei rubrici documente de tipul',
	'info_joindre_documents_article' => 'Puteţi să ataşaţi articolului dumneavoastră documente de tipul :',
	'info_l_article' => 'articolul',
	'info_la_breve' => 'ştirea',
	'info_la_rubrique' => 'rubrica',
	'info_langue_principale' => 'Limba principală a site-ului',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixeli',
	'info_les_auteurs_1' => 'de @les_auteurs@',
	'info_logo_format_interdit' => 'Doar viniétele cu formatul @formats@ sunt autorizate.',
	'info_logo_max_poids' => 'Viniétele trebuie în mod obligatoriu să fie mai mici de @maxi@ (acest fişier are @actuel@).',
	'info_mail_fournisseur' => 'dumneavoastră@furnizor.ro',
	'info_message_2' => 'MESAJ',
	'info_message_supprime' => 'MESAJ ŞTERS',
	'info_messages_nb' => '@nb@ messages',
	'info_messages_un' => '1 mesaj',
	'info_mise_en_ligne' => 'Data publicării :',
	'info_modification_parametres_securite' => 'modificări ale parametrilor de securitate',
	'info_mois_courant' => 'În timpul lunii :',
	'info_mot_cle_ajoute' => 'Cuvântul-cheie următor a fost adăugat la',
	'info_multi_herit' => 'Limba implicită',
	'info_multi_langues_soulignees' => '<u>Limbile subliniate</u> beneficiază de o traducere a tuturor textelor interfeţei. Dacă veţi selecţiona o astfel de limbă, numeroase elemente ale site-ului public (date, formulare) vor fi traduse în mod automat. Pentru limbile nesubliniate, aceste elemente vor apare în limba principală a site-ului.', # MODIF
	'info_multilinguisme' => 'Multilingvism',
	'info_nom_non_utilisateurs_connectes' => 'Numele dumneavoastră nu apare în lista utilizatorilor conectaţi.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Numele dumneavoastră apare în lista utilizatorilor conectaţi.', # MODIF
	'info_nombre_en_ligne' => 'Acum în linie :',
	'info_non_resultat' => 'Nici un rezultat pentru "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Nu puteţi utiliza mesageria internă a acestui site.',
	'info_nouveau_message' => 'AVEŢI UN NOU MESAJ',
	'info_nouveaux_messages' => 'AVEŢI @total_messages@ MESAJE NOI',
	'info_numero_abbreviation' => 'Nr ',
	'info_obligatoire' => 'Această informaţie este obligatorie',
	'info_pense_bete' => 'CIORNĂ',
	'info_petit_ecran' => 'Ecran mic',
	'info_petition_close' => 'Petiţie închisă',
	'info_pixels' => 'pixeli',
	'info_plusieurs_mots_trouves' => 'Mai multe cuvinte-cheie găsite pentru "@cherche_mot@":',
	'info_portfolio_automatique' => 'Portofoliu automatic :',
	'info_premier_resultat' => '[@debut_limit@ primele rezultate din @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primele rezultate din @total@]',
	'info_propose_1' => '[@nom_site_spip@] Propune : @titre@',
	'info_propose_2' => 'Articol propus
---------------',
	'info_propose_3' => 'Articolul "@titre@" este propus pentru publicare.',
	'info_propose_4' => 'Sunteţi invitat să consultaţi şi să vă exprimaţi opinia',
	'info_propose_5' => ' în forum-ul care îi este anexat. Acesta este disponibil la adresa :',
	'info_publie_01' => 'Articolul "@titre@" a fost validat de către @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICĂ : @titre@',
	'info_publie_2' => 'Articol publicat
--------------',
	'info_rechercher' => 'Căutaţi',
	'info_rechercher_02' => 'Căutaţi :',
	'info_remplacer_vignette' => 'Înlocuiţi viniéta implicită cu o viniétă personalizată :',
	'info_rubriques_nb' => '@nb@ rubrici',
	'info_rubriques_un' => '1 rubrică',
	'info_sans_titre_2' => 'fără titlu',
	'info_selectionner_fichier' => 'Puteţi selecţiona un fişier din directorul @upload@',
	'info_selectionner_fichier_2' => 'Selecţionaţi un fişier :',
	'info_sites_nb' => '@nb@ site-uri',
	'info_sites_un' => '1 site',
	'info_supprimer_vignette' => ' suprimaţi vinieta',
	'info_symbole_bleu' => 'Simbolul <b>albastru</b> indică o <b>ciornă</b>: adică un mesaj pentru folosinţa dumneavoastră personală.',
	'info_symbole_jaune' => 'Simbolul <b>galben</b> indică un <b>anunţ către toţi redactorii</b> : modificabil de către toţi administratorii şi vizibil pentru toţi redactorii.', # MODIF
	'info_symbole_vert' => 'Simbolul <b>verde</b> indică un <b>mesaj schimbat cu ceilalţi utilizatori</b> ai site-ului.', # MODIF
	'info_telecharger_nouveau_logo' => 'Încărcaţi o nouă viniétă :',
	'info_telecharger_ordinateur' => 'Încărcaţi de pe calculatorul dumneavoastră :',
	'info_tous_resultats_enregistres' => '[toate rezultatele sunt înregistrate]',
	'info_tout_afficher' => 'Afişaţi totul',
	'info_travaux_texte' => 'Acest site nu a fost încă configurat. Reveniţi altă dată...',
	'info_travaux_titre' => 'Site în lucru',
	'info_trop_resultat' => 'Prea multe rezultate pentru "@cherche_mot@" ; vă rugăm să micşoraţi domeniul de căutare.',
	'info_utilisation_messagerie_interne' => 'Utilizaţi sistemul de mesagerie internă al site-ului.',
	'info_valider_lien' => ' validaţi această legătură',
	'info_verifier_image' => ', vă rugăm să verificaţi că imaginile au fost transferate corect.',
	'info_vignette_defaut' => 'Vinietă implicită',
	'info_vignette_personnalisee' => 'Vinietă personalizată',
	'info_visite' => 'vizită :',
	'info_vos_rendez_vous' => 'Următoarele dumneavoastră întâlniri',
	'infos_vos_pense_bete' => 'Ciornele dumneavoastră',

	// L
	'label_poids_fichier' => 'Mărime',
	'lien_afficher_icones_seuls' => 'Afişaţi doar iconiţe',
	'lien_afficher_texte_icones' => 'Afişaţi iconiţe şi text',
	'lien_afficher_texte_seul' => 'Afişaţi doar text',
	'lien_liberer' => 'eliberaţi',
	'lien_liberer_tous' => 'Eliberaţi toate articolele',
	'lien_nouvea_pense_bete' => 'CIORNĂ NOUĂ',
	'lien_nouveau_message' => 'MESAJ NOU',
	'lien_nouvelle_annonce' => 'ANUNŢ NOU',
	'lien_petitions' => 'PETIŢIE',
	'lien_popularite' => 'popularitate : @popularite@%',
	'lien_racine_site' => 'RĂDĂCINA SITE-ULUI',
	'lien_reessayer' => 'reîncercaţi',
	'lien_repondre_message' => 'Răspundeţi la acest mesaj',
	'lien_supprimer' => 'ştergeţi',
	'lien_tout_afficher' => 'Afişaţi totul',
	'lien_visite_site' => 'vizitaţi acest site',
	'lien_visites' => '@visites@ vizite',
	'lien_voir_auteur' => 'Vedeţi acest autor',
	'ligne' => 'Linie',
	'login' => 'Conexiune',
	'login_acces_prive' => 'acces la secţiunea privată',
	'login_autre_identifiant' => 'conectare sub un alt cont',
	'login_cookie_accepte' => 'Vă rugăm să reglaţi navigatorul dumneavoastră de web în aşa fel încât să accepte cookies (cel puţin pentru acest site).',
	'login_cookie_oblige' => 'Pentru a fi identificat de o manieră sigură pe acest site va trebui să acceptaţi cookies.',
	'login_deconnexion_ok' => 'Deconectare OK.',
	'login_erreur_pass' => 'Eroare de parolă.',
	'login_espace_prive' => 'spaţiu privat',
	'login_identifiant_inconnu' => 'identificatorul « @login@ » este necunoscut.',
	'login_login' => 'Login :',
	'login_login2' => 'Login sau adresa email :',
	'login_login_pass_incorrect' => '(Login sau parolă incorectă.)',
	'login_motpasseoublie' => 'parolă uitată ?',
	'login_non_securise' => 'Atenţie, acest formular nu este securizat.
    Dacă nu doriţi ca parola dumneavoastră să poată fi interceptată pe net, vă rugăm să activaţi Javascript
    pentru navigatorul dumneavoastră de web şi',
	'login_nouvelle_tentative' => 'O nouă încercare',
	'login_par_ici' => 'Sunteţi înregistrat... vă rugam să veniţi pe aici...',
	'login_pass2' => 'Parolă :',
	'login_preferez_refuser' => '<b>Dacă preferaţi să refuzaţi cookies</b>, există o altă metodă de conectare (mai puţin sigură) la dispoziţia dumneavoastră :',
	'login_recharger' => 're-încărcaţi această pagină',
	'login_rester_identifie' => 'Rămâneţi autentificat pentru câteva zile', # MODIF
	'login_retour_public' => 'Înapoi la site-ul public',
	'login_retour_site' => 'Înapoi la site-ul public',
	'login_retoursitepublic' => 'înapoi la site-ul public',
	'login_securise' => 'Login securizat',
	'login_sinscrire' => 'înscrieţi-vă', # MODIF
	'login_test_navigateur' => 'test de navigator/reconectare',
	'login_verifiez_navigateur' => '(Verificaţi totuşi că navigatorul de web nu a memorat parola dumneavoastră...)',

	// M
	'masquer_colonne' => 'Mascaţi această coloană',
	'masquer_trad' => 'mascaţi traducerile',
	'module_fichiers_langues' => 'Fişiere de limbă',

	// N
	'navigateur_pas_redirige' => 'Dacă navigatorul dumneavoastră nu este redirijat în mod automatic, faceţi click aici pentru a continua.',
	'numero' => 'Număr',

	// O
	'occurence' => 'Ocurenţă',
	'onglet_affacer_base' => 'Ştergeţi baza',
	'onglet_auteur' => 'Autorul',
	'onglet_contenu_site' => 'Conţinutul site-ului',
	'onglet_evolution_visite_mod' => 'Evoluţie',
	'onglet_fonctions_avances' => 'Funcţii avansate',
	'onglet_informations_personnelles' => 'Informaţii personale',
	'onglet_interactivite' => 'Interactivitate',
	'onglet_messagerie' => 'Mesagerie',
	'onglet_repartition_rubrique' => 'Repartiţia pe rubrici',
	'onglet_save_restaur_base' => 'Salvaţi/restauraţi baza de date',
	'onglet_vider_cache' => 'Goliţi memoria tampon',

	// P
	'pass_choix_pass' => 'Vă rugăm să alegeţi noua dumneavoastră parolă :',
	'pass_erreur' => 'Eroare',
	'pass_erreur_acces_refuse' => '<b>Eroare :</b> nu mai aveţi acces la acest site.',
	'pass_erreur_code_inconnu' => '<b>Eroare :</b> acest cod nu corespunde nici unui vizitator având acces la site.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Eroare :</b> adresa <tt>@email_oubli@</tt> nu este înregistrată pe acest site.',
	'pass_erreur_non_valide' => '<b>Eroare :</b> acest email <tt>@email_oubli@</tt> nu este valabil !',
	'pass_erreur_probleme_technique' => '<b>Eroare :</b> din cauza unei probleme tehnice, email-ul nu a putut fi trimis.',
	'pass_espace_prive_bla' => 'Spaţiul privat al acestui site este deschis
  vizitatorilor după înscriere. Odată înregistrat
  veţi putea consulta articolele în curs de editare,
  veţi putea propune articole şi veţi putea participa la toate forum-urile.', # MODIF
	'pass_forum_bla' => 'Aţi cerut să interveniţi pe un forum
  rezervat vizitatorilor înregistraţi.', # MODIF
	'pass_indiquez_cidessous' => 'Vă rugăm să indicați adresa de email cu care v-aţi înregistrat în trecut.
Veţi primi un email care vă va indica paşii necesari recuperării accesului la site.',
	'pass_mail_passcookie' => '(acesta este un mesaj automatic)
Pentru a regăsi accesul la site-ul
@nom_site_spip@ (@adresse_site@)

Vă rugăm să vizitaţi adresa următoare :

    @sendcookie@

Veţi putea după aceea alege o nouă parolă şi veţi putea să vă reconectaţi la site.

', # MODIF
	'pass_mot_oublie' => 'Parolă uitată',
	'pass_nouveau_enregistre' => 'Noua dumneavoastră parolă a fost înregistrată.',
	'pass_nouveau_pass' => 'Parolă nouă',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Parolă uitată',
	'pass_quitter_fenetre' => 'Părăsiţi această fereastră',
	'pass_rappel_login' => 'Atenţie : identificatorul dumneavoastră (login) este « @login@ ».',
	'pass_recevoir_mail' => 'Veţi primi în curând un email care vă va indica cum puteţi să recuperaţi accesul la site.', # MODIF
	'pass_retour_public' => 'Întoarceţi-vă la site-ul public',
	'pass_rien_a_faire_ici' => 'Nimic de făcut aici.',
	'pass_vousinscrire' => 'Înscrieţi-vă pe acest site',
	'precedent' => 'precedent',
	'previsualisation' => 'pre-vizualizare',
	'previsualiser' => 'Pre-vizualizare',

	// R
	'retour' => 'Retur',

	// S
	'spip_conforme_dtd' => 'SPIP consideră acest document ca fiind conform cu DOCTYPE-ul său: ',
	'squelette' => 'schelet',
	'squelette_inclus_ligne' => 'schelet inclus, linia',
	'squelette_ligne' => 'schelet, linia',
	'stats_visites_et_popularite' => '@visites@ vizite ; popularitate : @popularite@',
	'suivant' => 'următorul',

	// T
	'taille_ko' => '@taille@ ko',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ octeţi',
	'taille_octets_bi' => '@taille@ octeţi',
	'texte_actualite_site_1' => 'Când veţi fi familiarizat cu interfaţa, puteţi face click pe «',
	'texte_actualite_site_2' => 'interfaţa completă',
	'texte_actualite_site_3' => '» pentru a vă deschide mai multe posibilităţi.',
	'texte_creation_automatique_vignette' => 'Crearea automatică de viniete de pre-vizualizare este activată pe acest site. Dacă veţi instala imagini cu ajutorul acestui formular în formatele @gd_formats@, ele vor fi acompaniate de o vinietă de o talie maximală de @taille_preview@ pixeli.',
	'texte_documents_associes' => 'Documentele următoare sunt asociate articolului,
   dar nu au fost inserate în mod direct. În funcţie de punerea în pagină a site-ului public,
  acestea ar putea apărea ca documente ataşate.',
	'texte_erreur_mise_niveau_base' => 'Eroare la nivelul bazei de date în timpul actualizării.
  Imaginea <b>@fichier@</b> nu a trecut (articolul @id_article@).
  Notaţi această referinţă, re-încercaţi o actualizare şi verificaţi dacă imaginile apar
  în articole.',
	'texte_erreur_visiteur' => 'Aţi încercat să accesaţi secţiunea protejată cu un nume de utilizator fără drepturi.',
	'texte_inc_auth_1' => 'V-aţi identificat cu
  login <b>@auth_login@</b>, dar acesta nu (mai) există în baza de date.
  Încercaţi să',
	'texte_inc_auth_2' => 'vă reconectaţi',
	'texte_inc_auth_3' => ', după ce, eventual, aţi părăsit şi redemarat navigatorul de web.',
	'texte_inc_config' => 'Modificările efectuate în aceste pagini au influenţă directă asupra funcţionării site-ului. Vă recomandăm să nu interveniţi atât timp cât nu sunteţi familiarizat cu funcţionarea sistemului SPIP. <br /><br /><b>În
 general, este recomandat să lăsaţi aceste pagini în sarcina webmaster-ului principal al acestui site.</b>',
	'texte_inc_meta_1' => 'Sistemul a întâlnit o eroare la scrierea fişierului <code>@fichier@</code>. Vă rugam ca, în calitate de administrator al acestui site,', # MODIF
	'texte_inc_meta_2' => 'să verificaţi drepturile de scriere',
	'texte_inc_meta_3' => 'în directorul <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'în curs de redactare',
	'texte_statut_poubelle' => 'la coşul de gunoi',
	'texte_statut_propose_evaluation' => 'propus pentru evaluare',
	'texte_statut_publie' => 'publicat în direct',
	'texte_statut_refuse' => 'refuzat',
	'titre_ajouter_mot_cle' => 'ADĂUGAŢI UN CUVÂNT-CHEIE :',
	'titre_cadre_raccourcis' => 'SCURTĂTURI :',
	'titre_changer_couleur_interface' => 'Schimbă culoarea interfeţei',
	'titre_image_admin_article' => 'Puteţi administra acest articol',
	'titre_image_administrateur' => 'Administrator', # MODIF
	'titre_image_aide' => 'Ajutor despre acest element',
	'titre_image_auteur_supprime' => 'Autor suprimat',
	'titre_image_redacteur' => 'Redactor fără acces',
	'titre_image_redacteur_02' => 'Redactor',
	'titre_image_visiteur' => 'Vizitator',
	'titre_joindre_document' => 'ATAŞAŢI DOCUMENT',
	'titre_mots_cles' => 'CUVINTE-CHEIE',
	'titre_probleme_technique' => 'Atenţie : o problemă tehnică (server SQL) împiedică accesul la această parte a site-ului. Vă mulţumim pentru înţelegere.',
	'titre_publier_document' => 'PUBLICĂ UN DOCUMENT ÎN ACEASTĂ RUBRICĂ',
	'titre_signatures_attente' => 'Semnături în aşteptarea validării',
	'titre_signatures_confirmees' => 'Semnături confirmate',
	'titre_statistiques' => 'Statisticile site-ului',
	'titre_titre_document' => 'Titlul documentului:',
	'todo' => 'de făcut',
	'trad_reference' => '(referinţa traducerilor)',

	// Z
	'zbug_balise_b_aval' => ' : element B înainte',
	'zbug_balise_inexistante' => 'Baliza @balise@ nu este bine declarată pentru @from@',
	'zbug_balise_sans_argument' => 'Argument lipsă în baliza @balise@',
	'zbug_boucle' => 'buclă',
	'zbug_boucle_recursive_undef' => 'Buclă recursivă nedefinită: @nom@',
	'zbug_calcul' => 'calcul',
	'zbug_champ_hors_boucle' => 'Câmp @champ@ în afara buclei',
	'zbug_champ_hors_motif' => 'Câmp @champ@ în afara contextului buclei @motif@',
	'zbug_code' => 'cod',
	'zbug_critere_inconnu' => 'Criteriu necunoscut @critere@',
	'zbug_distant_interdit' => 'Extern interzis',
	'zbug_doublon_table_sans_cle_primaire' => 'Dubluri într-o tabelă fără cheie primară atomică',
	'zbug_doublon_table_sans_index' => 'Dubluri într-o tabelă fără index',
	'zbug_erreur_boucle_double' => 'Bucla @id@: definiţie dublă',
	'zbug_erreur_boucle_fermant' => 'Bucla @id@: tag-ul de închidere lipseşte',
	'zbug_erreur_boucle_syntaxe' => 'Sintaxă incorectă pentru bucla @id@',
	'zbug_erreur_compilation' => 'Eroare de compilare',
	'zbug_erreur_execution_page' => 'Eroare de execuţie',
	'zbug_erreur_filtre' => 'Filtru @filtre@ nedefinit',
	'zbug_erreur_meme_parent' => 'Criteriul {meme_parent} nu se aplică decât buclelor (FORUMS) sau (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Eroare/Erori în schelet',
	'zbug_hors_compilation' => 'Fără compilare',
	'zbug_info_erreur_squelette' => 'Eroare pe site',
	'zbug_inversion_ordre_inexistant' => 'Inversie de ordin necunoscut',
	'zbug_pagination_sans_critere' => 'Baliza #PAGINATION făr criteriu {pagination} sau folosit într-o buclă recursivă',
	'zbug_parametres_inclus_incorrects' => 'Parametru de includere incorect: @param@',
	'zbug_profile' => 'Timp de calcul : @time@',
	'zbug_resultat' => 'rezultat',
	'zbug_serveur_indefini' => 'Server SQL nedefinit',
	'zbug_statistiques' => 'Statisticile cererilor SQL clasate după durată',
	'zbug_table_inconnue' => 'Tabela SQL « @table@ » necunoscută',
	'zxml_connus_attributs' => 'atribute cunoscute',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atribut necunoscut',
	'zxml_inconnu_balise' => 'baliză (tag) necunoscută',
	'zxml_inconnu_entite' => 'entitate necunoscută',
	'zxml_inconnu_id' => 'ID necunoscut',
	'zxml_mais_de' => 'dar de',
	'zxml_non_conforme' => 'nu este conform cu motivul',
	'zxml_non_fils' => 'nu este un fiu al',
	'zxml_nonvide_balise' => 'baliză (tag) ne-vidă',
	'zxml_obligatoire_attribut' => 'atribut obligatoriu dar absent din',
	'zxml_succession_fils_incorrecte' => 'succesiune incorectă de fii',
	'zxml_survoler' => 'planaţi pentru a vedea corect',
	'zxml_valeur_attribut' => 'valoarea atributului',
	'zxml_vide_balise' => 'baliză (tag) vidă',
	'zxml_vu' => 'văzut înainte',
];
